@@ -709,37 +709,59 @@ printdev(struct tcb *tcp, int fd, const char *path, const struct finfo *finfo)
 	return false;
 }
 
-pid_t
-pidfd_get_pid(pid_t pid_of_fd, int fd)
+typedef bool (*scan_fdinfo_fn)(const char *value, void *data);
+
+static bool
+scan_fdinfo(pid_t pid_of_fd, int fd, const char *search_pfx,
+	    size_t search_pfx_len, scan_fdinfo_fn fn, void *data)
 {
 	int proc_pid = 0;
 	translate_pid(NULL, pid_of_fd, PT_TID, &proc_pid);
 	if (!proc_pid)
-		return -1;
+		return false;
 
 	char fdi_path[sizeof("/proc/%u/fdinfo/%u") + 2 * sizeof(int) * 3];
 	xsprintf(fdi_path, "/proc/%u/fdinfo/%u", proc_pid, fd);
 
 	FILE *f = fopen_stream(fdi_path, "r");
 	if (!f)
-		return -1;
+		return false;
 
-	static const char pid_pfx[] = "Pid:\t";
 	char *line = NULL;
 	size_t sz = 0;
-	pid_t pid = -1;
-	while (getline(&line, &sz, f) > 0) {
-		const char *pos = STR_STRIP_PREFIX(line, pid_pfx);
-		if (pos == line)
-			continue;
+	bool result = false;
 
-		pid = string_to_uint_ex(pos, NULL, INT_MAX, "\n");
-		break;
+	while (getline(&line, &sz, f) > 0) {
+		const char *value =
+			str_strip_prefix_len(line, search_pfx, search_pfx_len);
+		if (value != line && fn(value, data)) {
+			result = true;
+			break;
+		}
 	}
 
 	free(line);
 	fclose(f);
 
+	return result;
+}
+
+static bool
+parse_fdinfo_pid(const char *value, void *data)
+{
+	pid_t *pid = data;
+	*pid = string_to_uint_ex(value, NULL, INT_MAX, "\n");
+	return true;
+}
+
+pid_t
+pidfd_get_pid(pid_t pid_of_fd, int fd)
+{
+	static const char pid_pfx[] = "Pid:\t";
+	pid_t pid = -1;
+
+	scan_fdinfo(pid_of_fd, fd, pid_pfx, sizeof(pid_pfx) - 1,
+		    parse_fdinfo_pid, &pid);
 	return pid;
 }
 
@@ -768,6 +790,47 @@ printpidfd(pid_t pid_of_fd, int fd, const char *path)
 	return true;
 }
 
+static bool
+print_fdinfo_sigmask(const char *value, void *data)
+{
+#ifdef WORDS_BIGENDIAN
+	unsigned int pos_xor_mask = current_wordsize - 1;
+#else
+	unsigned int pos_xor_mask = 0;
+#endif
+	size_t sigset_size = strlen(value) / 2;
+	uint8_t *sigmask = xmalloc(sigset_size);
+
+	for (size_t i = 0; i < sigset_size; ++i) {
+		uint8_t byte;
+		if (sscanf(value + i * 2, "%02hhx", &byte) != 1) {
+			free(sigmask);
+			return false;
+		}
+		sigmask[(sigset_size - 1 - i) ^ pos_xor_mask] = byte;
+	}
+
+	tprint_associated_info_begin();
+	tprints_string(sprintsigmask_n("signalfd:", sigmask, sigset_size));
+	tprint_associated_info_end();
+
+	free(sigmask);
+	return true;
+}
+
+static bool
+printsignalfd(pid_t pid_of_fd, int fd, const char *path)
+{
+	static const char signalfd_path[] = "anon_inode:[signalfd]";
+	static const char sigmask_pfx[] = "sigmask:\t";
+
+	if (strcmp(path, signalfd_path))
+		return false;
+
+	return scan_fdinfo(pid_of_fd, fd, sigmask_pfx, sizeof(sigmask_pfx) - 1,
+			   print_fdinfo_sigmask, NULL);
+}
+
 static void
 print_quoted_string_in_angle_brackets(const char *str, const bool deleted)
 {
@@ -799,6 +862,9 @@ printfd_pid_with_finfo(struct tcb *tcp, pid_t pid, int fd, const struct finfo *f
 		if (is_number_in_set(DECODE_FD_PIDFD, decode_fd_set) &&
 		    printpidfd(pid, fd, path))
 			goto printed;
+		if (is_number_in_set(DECODE_FD_SIGNALFD, decode_fd_set) &&
+		    printsignalfd(pid, fd, path))
+			goto printed;
 		if (is_number_in_set(DECODE_FD_PATH, decode_fd_set))
 			print_quoted_string_in_angle_brackets(path,
 							      finfo? finfo->deleted: deleted);
