@@ -40,6 +40,8 @@ cond_def()
 {
 	local line
 	line="$1"; shift
+	local xlat_type
+	xlat_type="$1"; shift
 
 	local val
 	val="${line%%[!A-Za-z0-9_]*}"
@@ -54,15 +56,47 @@ cond_def()
 	fi
 
 	if [ -n "$def" ]; then
-		printf "%s\n" \
-			"#if defined($val) || (defined(HAVE_DECL_$val) && HAVE_DECL_$val)" \
-			"DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE" \
-			"static_assert(($val) == ($def), \"$val != $def\");" \
-			"DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE" \
-			"#else" \
-			"# define $val $def" \
-			"#endif"
+		[ -n "$unconditional" ] ||
+			printf '%s\n' \
+				"#if defined($val) || (defined(HAVE_DECL_$val) && HAVE_DECL_$val)"
+		[ -n "$nocheckval" ] ||
+			printf '%s\n' \
+				"DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE" \
+				"static_assert(($val) == ($def), \"$val != $def\");" \
+				"DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE"
+		[ -n "$unconditional" ] ||
+			printf '%s\n' \
+				"#else" \
+				"# define $val $def" \
+				"#endif"
 	fi
+
+	if [ XT_SORTED = "$xlat_type" ]; then
+		[ -n "$unconditional" ] ||
+			printf '%s\n' \
+				"#if defined($val) || (defined(HAVE_DECL_$val) && HAVE_DECL_$val)"
+		check_sort_order "$val"
+		[ -n "$unconditional" ] ||
+			printf '%s\n' "#endif"
+	fi
+
+}
+
+check_sort_order()
+{
+	local val
+	val="$1"; shift
+
+	cat <<-EOF
+		#if defined XLAT_PREV_VAL
+		static_assert((unsigned long long) ($val)
+			      > (unsigned long long) (XLAT_PREV_VAL),
+			      "Incorrect order in #sorted xlat: $val"
+			      " is not larger than the previous value");
+		#endif
+		#undef XLAT_PREV_VAL
+		#define XLAT_PREV_VAL ($val)
+	EOF
 }
 
 print_xlat()
@@ -108,26 +142,29 @@ print_xlat_pair()
 cond_xlat()
 {
 	echo "$1" | {
-		local val def m xlat
+		local val def m is_shift='' xlat
 
 		read val def
 
 		m="${val%%|*}"
+		[ "${m}" = "${m#1<<}" ] || is_shift=1
 
-		if [ "${m}" = "${m#1<<}" ]; then
+		if [ -z "$is_shift$nocheckval" ]; then
 			xlat="$(print_xlat "${val}")"
-		else
+		elif [ -n "$is_shift" ]; then
 			m="${m#1<<}"
 			xlat="$(print_xlat_pair "1ULL<<${val#1<<}" "${val}" "$m")"
+		else
+			xlat="$(print_xlat_pair "${def}" "${val}" "$m")"
 		fi
 
-		if [ -z "${def}" ]; then
-			printf "%s\n" \
+		if [ -z "${def}${unconditional}" ]; then
+			printf '%s\n' \
 				"#if defined(${m}) || (defined(HAVE_DECL_${m}) && HAVE_DECL_${m})" \
 				" ${xlat}" \
 				"#endif"
 		else
-			echo "$xlat"
+			printf '%s\n' "$xlat"
 		fi
 	}
 
@@ -170,7 +207,7 @@ gen_header()
 
 	EOF
 
-	local unconditional= line
+	local unconditional='' nocheckval='' line
 	# 1st pass: output directives.
 	while read -r line; do
 		case "$line" in
@@ -187,6 +224,12 @@ gen_header()
 		'#unconditional')
 			unconditional=1
 			;;
+		'#checkval')
+			nocheckval=
+			;;
+		'#nocheckval')
+			nocheckval=1
+			;;
 		'#val_type '*)
 			# to be processed during 2nd pass
 			;;
@@ -207,13 +250,21 @@ gen_header()
 			echo "${line}"
 			;;
 		[A-Z_]*)
-			[ -n "$unconditional" ] ||
-				cond_def "$line"
+			cond_def "$line" "$xlat_type"
+			;;
+		'1<<'[A-Z_]*)	# symbolic constants with shift
+			[ XT_SORTED != "$xlat_type" ] ||
+				check_sort_order "1ULL<<${line#1<<}"
+			;;
+		[0-9]*)	# numeric constants
+			[ XT_SORTED != "$xlat_type" ] ||
+				check_sort_order "${line}"
 			;;
 		esac
 	done < "$input"
 
 	cat <<-EOF
+		#undef XLAT_PREV_VAL
 
 		#ifndef XLAT_MACROS_ONLY
 
@@ -260,7 +311,9 @@ gen_header()
 	echo "DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE"
 	echo "static const struct xlat_data ${name}_xdata[] = {"
 
-	unconditional= val_type=
+	unconditional=
+	nocheckval=
+	val_type=
 	# 2nd pass: output everything.
 	while read -r line; do
 		case "$line" in
@@ -277,6 +330,12 @@ gen_header()
 		'#unconditional')
 			unconditional=1
 			;;
+		'#checkval')
+			nocheckval=
+			;;
+		'#nocheckval')
+			nocheckval=1
+			;;
 		'#sorted'|'#sorted '*)
 			;;
 		'#value_indexed')
@@ -289,18 +348,10 @@ gen_header()
 			val_type="${line#\#val_type }"
 			;;
 		[A-Z_!]*)	# symbolic constants
-			if [ -n "${unconditional}" ]; then
-				print_xlat "${line}"
-			else
-				cond_xlat "${line}"
-			fi
+			cond_xlat "${line}"
 			;;
 		'1<<'[A-Z_]*)	# symbolic constants with shift
-			if [ -n "${unconditional}" ]; then
-				print_xlat_pair "1ULL<<${line#1<<}" "${line}" "${line#1<<}"
-			else
-				cond_xlat "${line}"
-			fi
+			cond_xlat "${line}"
 			;;
 		[0-9]*)	# numeric constants
 			print_xlat "${line}"
