@@ -1,7 +1,7 @@
 /*
  * IFLA_LINKINFO netlink attribute decoding check.
  *
- * Copyright (c) 2018-2021 The strace developers.
+ * Copyright (c) 2018-2023 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -241,30 +241,6 @@
 				printf("]]"));				\
 	} while (0)
 
-static const char *
-clock_t_str(uint64_t val, char *str, size_t str_size)
-{
-	static long clk_tck;
-	static int precision;
-
-	if (!clk_tck) {
-		clk_tck = sysconf(_SC_CLK_TCK);
-		precision = clk_tck > 1 ? MIN((int) ceil(log10(clk_tck - 1)), 9)
-					: 0;
-	}
-
-	if ((clk_tck > 0) && val) {
-		snprintf(str, str_size, "%" PRIu64 " /* %" PRIu64 ".%0*u s */",
-			 val, val / clk_tck, precision,
-			 (unsigned) round(((double) (val % clk_tck) / clk_tck)
-					  * pow(10, precision)));
-	} else {
-		snprintf(str, str_size, "%" PRIu64, val);
-	}
-
-	return str;
-}
-
 int
 main(void)
 {
@@ -581,17 +557,19 @@ main(void)
 			"\"\\x01\\x00\\x00\\x00\\x02\\x00\\x00\""),
 		  "{optval=1<<BR_BOOLOPT_NO_LL_LEARN"
 		  ", optmask=1<<BR_BOOLOPT_MCAST_VLAN_SNOOPING}" },
-		{ { .optval = 0xdeadfaec, .optmask = 0xbadc0dec },
-		  BE_LE("\"\\xde\\xad\\xfa\\xec\\xba\\xdc\\x0d\"",
-			"\"\\xec\\xfa\\xad\\xde\\xec\\x0d\\xdc\""),
-		  "{optval=0xdeadfaec /* 1<<BR_BOOLOPT_??? */"
-		  ", optmask=0xbadc0dec /* 1<<BR_BOOLOPT_??? */}" },
+		{ { .optval = 0xdeadfae8, .optmask = 0xbadc0de8 },
+		  BE_LE("\"\\xde\\xad\\xfa\\xe8\\xba\\xdc\\x0d\"",
+			"\"\\xe8\\xfa\\xad\\xde\\xe8\\x0d\\xdc\""),
+		  "{optval=0xdeadfae8 /* 1<<BR_BOOLOPT_??? */"
+		  ", optmask=0xbadc0de8 /* 1<<BR_BOOLOPT_??? */}" },
 		{ { .optval = 0xfacebeef, .optmask = 0xfeedcafe },
 		  BE_LE("\"\\xfa\\xce\\xbe\\xef\\xfe\\xed\\xca\"",
 			"\"\\xef\\xbe\\xce\\xfa\\xfe\\xca\\xed\""),
 		  "{optval=1<<BR_BOOLOPT_NO_LL_LEARN"
-			  "|1<<BR_BOOLOPT_MCAST_VLAN_SNOOPING|0xfacebeec"
-		  ", optmask=1<<BR_BOOLOPT_MCAST_VLAN_SNOOPING|0xfeedcafc}" },
+			 "|1<<BR_BOOLOPT_MCAST_VLAN_SNOOPING"
+			 "|1<<BR_BOOLOPT_MST_ENABLE|0xfacebee8"
+		  ", optmask=1<<BR_BOOLOPT_MCAST_VLAN_SNOOPING"
+		           "|1<<BR_BOOLOPT_MST_ENABLE|0xfeedcaf8}" },
 	};
 	for (size_t k = 0; k < ARRAY_SIZE(boolopts); k++) {
 		TEST_NESTED_LINKINFO(fd, nlh0, IFLA_INFO_KIND,
@@ -919,7 +897,7 @@ main(void)
 		{ 0, "IFLA_BRPORT_UNSPEC" },
 		{ 24, "IFLA_BRPORT_FLUSH" },
 		{ 26, "IFLA_BRPORT_PAD" },
-		{ 39, "0x27 /* IFLA_BRPORT_??? */" },
+		{ 43, "0x2b /* IFLA_BRPORT_??? */" },
 		{ 2989, "0xbad /* IFLA_BRPORT_??? */" },
 	};
 
@@ -961,6 +939,8 @@ main(void)
 		{ ARG_STR(IFLA_BRPORT_ISOLATED) },
 		{ ARG_STR(IFLA_BRPORT_MRP_RING_OPEN) },
 		{ ARG_STR(IFLA_BRPORT_MRP_IN_OPEN) },
+		{ ARG_STR(IFLA_BRPORT_LOCKED) },
+		{ ARG_STR(IFLA_BRPORT_MAB) },
 	};
 
 	for (size_t k = 0; k < ARRAY_SIZE(u8_brport_attrs); k++) {
@@ -1012,6 +992,8 @@ main(void)
 		{  3, "IFLA_BRPORT_COST" },
 		{ 37, "IFLA_BRPORT_MCAST_EHT_HOSTS_LIMIT" },
 		{ 38, "IFLA_BRPORT_MCAST_EHT_HOSTS_CNT" },
+		{ ARG_STR(IFLA_BRPORT_MCAST_N_GROUPS) },
+		{ ARG_STR(IFLA_BRPORT_MCAST_MAX_GROUPS) },
 	};
 
 	for (size_t k = 0; k < ARRAY_SIZE(u32_brport_attrs); k++) {
